.. _upcoming:

Upcoming changes
################

An ever changing topic - Please take a look at the current
`milestones <https://github.com/jgliss/geonum/milestones>`__
for new features, bug fixes, etc that are in the pipeline.

As this project is developed privately, things may take a while and we
encourage interested users to contribute to geonum.

.. _contribute:

Contribute
##########

We appreciate very much any contribution from users or developers to geonum.

There are many ways to contribute to open source software, here are some
examples:

- **I am a happy user of geonum**: Tell others or us.
- **I found a bug**: Create an
  `issue <https://github.com/jgliss/geonum/issues>`__.
- **I have a good idea for a new feature**: Tell us, by creating an
  `issue <https://github.com/jgliss/geonum/issues>`__.
- **I want to contribute to the code by, e.g.**:

    - Improving the documentation.
    - Fixing a bug.
    - Implementing a new feature.
    - Adding an example or tutorial.

  Fork the `GitHub repo <https://github.com/jgliss/geonum>`__, make your changes and create a pull request
  from your fork.